[Zooimage-commits] r256 - in pkg/zooimage: . R inst/gui/errorcorrection

noreply at r-forge.r-project.org noreply at r-forge.r-project.org
Tue Oct 27 15:54:04 CET 2015


Author: phgrosjean
Date: 2015-10-27 15:54:03 +0100 (Tue, 27 Oct 2015)
New Revision: 256

Modified:
   pkg/zooimage/NEWS
   pkg/zooimage/R/gui.R
   pkg/zooimage/inst/gui/errorcorrection/server.R
Log:
Use .zidb in processSamples()

Modified: pkg/zooimage/NEWS
===================================================================
--- pkg/zooimage/NEWS	2015-10-09 15:46:49 UTC (rev 255)
+++ pkg/zooimage/NEWS	2015-10-27 14:54:03 UTC (rev 256)
@@ -4,7 +4,9 @@
 
 * Cells counting per colonies (per particles) is now provided.
 
+* processSamples() now look for .zidb files instead of .zid files.
 
+
 == Changes in zooimage 5.4-2
 
 * Correction of one bug in the function addVigsToTrain().

Modified: pkg/zooimage/R/gui.R
===================================================================
--- pkg/zooimage/inst/gui/errorcorrection/server.R	2015-10-09 15:46:49 UTC (rev 255)
+++ pkg/zooimage/inst/gui/errorcorrection/server.R	2015-10-27 14:54:03 UTC (rev 256)
@@ -79,7 +79,7 @@
 #                 warning("No contextual samples selected! Initial training set will be used.")
 #             } else {
 #                 ## TODO: merge with activeLearningGUI
-#                 .ZI$Train <- addItemsToTrain(.ZI$Train, CtxSmp,
+#                 .ZITrain <- addItemsToTrain(.ZITrain, CtxSmp,
 #                     dropItemsToTrain = dropItemsToTrain)
 #             }
             .ZITrain <- activeLearning(.ZITrain)



More information about the Zooimage-commits mailing list
--- pkg/zooimage/R/gui.R	2015-10-09 15:46:49 UTC (rev 255)
+++ pkg/zooimage/R/gui.R	2015-10-27 14:54:03 UTC (rev 256)
@@ -1357,13 +1357,13 @@
 	if (!length(smplist) || smplist == "")
 		stop("No sample found in the description file!")
 	
 	## Are there corresponding .zid files for all samples?
 	zisdir <- dirname(zisfile)
 	if (zisdir == ".") zisdir <- getwd()
-	zidfiles <- file.path(zisdir, paste(smplist, ".zid", sep = ""))
-	if (!all(file.exists(zidfiles)) ||
-		!all(regexpr("[.][zZ][iI][dD]$", zidfiles) > 0))
-		stop("One or more .zid files do not exist or is invalid!")
+	zidbfiles <- file.path(zisdir, paste(smplist, ".zidb", sep = ""))
+	if (!all(file.exists(zidbfiles)) ||
+		!all(regexpr("[.][zZ][iI][dD][bB]$", zidbfiles) > 0))
+		stop("One or more .zidb files do not exist or is invalid!")
 	
 	## Get a classifier
 	ZIC <- getTemp("ZI.ClassName")
@@ -1413,7 +1413,6 @@
 		biomass = conv, breaks = brks)
 	## TODO: possibly export result in a file...
 	
-	
 	## Assign this result to the variable
 	.assignGlobal(name, res)
 	## Remember the name of the variable
@@ -1357,13 +1357,13 @@
 		stop("No sample found in the description file!")
 	
-	## Are there corresponding .zid files for all samples?
+	## Are there corresponding .zidb files for all samples?
 	zisdir <- dirname(zisfile)
 	if (zisdir == ".") zisdir <- getwd()

Modified: pkg/zooimage/inst/gui/errorcorrection/server.R
===================================================================